# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

# Custom build target that removes .js.map files for published
# dist files.
import glob
import json
import os
import subprocess

from hatch_jupyter_builder import npm_builder
from packaging.version import Version


def builder(target_name, version, *args, **kwargs):
    # Allow building from sdist without node.
    if target_name == "wheel" and not os.path.exists("dev_mode"):
        return

    npm_builder(target_name, version, *args, **kwargs)

    if version == "editable":
        return

    files = glob.glob("jupyterlab/static/*.js.map")
    for path in files:
        os.remove(path)

    target = glob.glob("jupyterlab/static/package.json")[0]
    with open(target) as fid:
        npm_version = json.load(fid)["jupyterlab"]["version"]

    py_version = subprocess.check_output(["hatchling", "version"])  # noqa S603 S607
    py_version = py_version.decode("utf-8").strip()

    if Version(npm_version) != Version(py_version):
        msg = "Version mismatch, please run `npm run prepare:python-release`"
        raise ValueError(msg)



# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

import json
import os.path as osp

from jupyterlab_server.process import which
from jupyterlab_server.process_app import ProcessApp

HERE = osp.dirname(osp.realpath(__file__))


def _jupyter_server_extension_points():
    return [{"module": __name__, "app": NodeApp}]


class NodeApp(ProcessApp):
    name = __name__
    serverapp_config = {"allow_origin": "*"}

    def get_command(self):
        """Get the command and kwargs to run."""
        # Run the node script with command arguments.
        config = {
            "baseUrl": "http://localhost:{}{}".format(
                self.serverapp.port, self.settings["base_url"]
            ),
            "token": self.settings["token"],
        }

        with open(osp.join(HERE, "config.json"), "w") as fid:
            json.dump(config, fid)

        cmd = [which("node"), "index.js", "--jupyter-config-data=./config.json"]
        return cmd, {"cwd": HERE}


if __name__ == "__main__":
    NodeApp.launch_instance()



# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

from jupyterlab.galata import configure_jupyter_server

configure_jupyter_server(c)
c.LabApp.dev_mode = True

# Uncomment to set server log level to debug level
# c.ServerApp.log_level = "DEBUG"



# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

import os
import subprocess

here = os.path.abspath(os.path.dirname(__file__))


# Workaround for https://github.com/git-for-windows/git/issues/607
if os.name == "nt":
    for root, dnames, _ in os.walk(here):
        if "node_modules" in dnames:
            subprocess.check_call(
                ["rmdir", "/s", "/q", "node_modules"],  # noqa S602 S607
                cwd=root,
                shell=True,  # noqa S602 S607
            )
            dnames.remove("node_modules")


subprocess.check_call("python -m pip uninstall -y jupyterlab".split(), cwd=here)  # noqa S603


def resolve_pattern(pat):
    """handle a leading `#` or `@` in a pattern"""
    pat = pat.strip()

    if not pat or pat.startswith("#"):
        return []
    elif pat.startswith("@"):
        raw = pat[1:]
        return [raw, f"!packages/**/{raw}", f"!**/node_modules/**/{raw}"]
    else:
        return [pat]


# get the exclude patterns listed in .cleanignore
with open(os.path.join(here, ".cleanignore")) as f:
    git_clean_exclude = [f"--exclude={pat}" for line in f for pat in resolve_pattern(line)]

git_clean_command = ["git", "clean", "-dfx", *git_clean_exclude]
subprocess.check_call(git_clean_command, cwd=here)  # noqa S603
